summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/netsurf/browser_window.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/netsurf/browser_window.h b/include/netsurf/browser_window.h
index 0b140521f..9bb191c3f 100644
--- a/include/netsurf/browser_window.h
+++ b/include/netsurf/browser_window.h
@@ -300,10 +300,11 @@ void browser_window_stop(struct browser_window *bw);
/**
* Reload the page in a browser window.
*
* \param bw browser window
* \param all whether to reload all objects associated with the page
*/
-void browser_window_reload(struct browser_window *bw, bool all);
+nserror browser_window_reload(struct browser_window *bw, bool all);
/**
@@ -300,10 +300,11 @@ void browser_window_stop(struct browser_window *bw);
* Reload the page in a browser window.
*
- * \param bw browser window
- * \param all whether to reload all objects associated with the page
+ * \param bw browser window
+ * \param all whether to reload all objects associated with the page
+ * \return NSERROR_OK on success else error code.
*/